@@ -9,7 +9,7 @@ subroutine Dcl_2D_cont_shade( outname,  &
   &  shade_min, shade_max, x_title, y_title,  &
   &  form_typec, form_types, viewx_min, viewx_max,  &
   &  viewy_min, viewy_max, color_num, cont_num, nongrid,  &
-  &  xg, yg, mono, mono_val, mono_lev )
+  &  xg, yg, mono, mono_val, mono_lev, trigleg )
   ! 2  2 ѿȥ顼ɤ褹.
   use dcl
   implicit none
@@ -52,9 +52,11 @@ subroutine Dcl_2D_cont_shade( outname,  &
                     ! ͤ mono_lev + 1 ʬ¸ߤʤФʤʤ.
   integer, intent(in), optional :: mono_lev(:)  ! ȡޥåֹ. dcl  3 
                     ! mono=.true. ΤȤꤷʤȥ顼֤.
+  character(1), intent(in), optional :: trigleg  ! infinity ˻ѷɽ
+                    ! ͤ tone_bar  trigle Ʊ.
   integer :: i, j, k  ! ź
   integer :: nx, ny, s_num, c_num
-  real :: vx_min, vx_max, vy_min, vy_max
+  real :: vx_min, vx_max, vy_min, vy_max, vy_tonemin, vy_tonemax
   real :: undef, RMISS
   logical :: monoto
 
@@ -181,8 +183,24 @@ subroutine Dcl_2D_cont_shade( outname,  &
      end do
   end if
 
+  if(present(trigleg))then
+     select case(trigleg)
+     case ('a')
+        vy_tonemin=vy_min+0.025  ! ѷΥǥեȤĹդĹȰ
+        vy_tonemax=vy_max-0.025
+     case ('u')
+        vy_tonemin=vy_min+0.025
+     case ('d')
+        vy_tonemax=vy_max-0.025
+     end select
 
-  call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types, mono_log=monoto )
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,  &
+  &                 vy_tonemin, vy_tonemax, form_types, mono_log=monoto,  &
+  &                 trigle=trigleg )
+  else
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,  &
+  &                 vy_min, vy_max, form_types, mono_log=monoto )
+  end if
 
 end subroutine
 
@@ -1566,7 +1584,9 @@ end subroutine
 
 !---------------------------------------------------------
 
-subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max, vy_min, vy_max, form_types, mono_log )  ! ˥ȡСư
+subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max,  &
+  &                  vy_min, vy_max, form_types, mono_log, trigle,  &
+  &                  tricmin, tricmax, trifact )  ! ˥ȡСư
   use dcl
   implicit none
   integer, intent(in) :: color_num  ! Ѥ뿧ο
@@ -1578,11 +1598,26 @@ subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max, vy_min, vy
   real, intent(in) :: vy_max  ! ӥ塼ݡȤ y κ
   character(6), intent(in) :: form_types  ! ٥եޥå
   logical, intent(in), optional :: mono_log
+  character(1), intent(in), optional :: trigle  ! grads ʻѷФɤ
+                ! [u] = , [d] = , [a] = ξ, ǥեȤǤʤ
+  integer, intent(in), optional :: tricmin  ! üѤ顼ޥåֹ 5 
+  integer, intent(in), optional :: tricmax  ! üѤ顼ޥåֹ 5 
+                ! οꤵƤʤ, color_setting ǥåȤƤ뿧Ȥ褦ˤ.
+  real, intent(in), optional :: trifact  ! ѷι⤵ (դƱĹ 1 ȤƤ factor ܤΨ. ǥեȤ 1.)
+  real :: RMISS
   integer :: k
   real :: pi(2,color_num+1)
   real :: dp
   real :: coldim1(color_num+1), coldim2(color_num/2+1)
   logical :: monoto  ! Υȡν
+  real, dimension(3) :: triux, triuy, tridx, tridy
+  real :: factoru, clev1, clev2
+  integer :: tricmin_num, tricmax_num
+          ! ¿ѷΰλǤ, ѷĺֺɸ狼Ф褤Τ,
+          ! ƺɸ 3 ɬ
+
+!-- Dcl ¦ undef ͥå
+   CALL GLRGET( 'RMISS', RMISS )
 
 !-- ץν
   if(present(mono_log))then
@@ -1591,6 +1626,56 @@ subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max, vy_min, vy
      monoto=.false.
   end if
 
+  if(present(trigle))then
+     if(present(trifact))then
+        factoru=trifact
+     else
+        factoru=1.0
+     end if
+
+     if(present(tricmin))then
+        tricmin_num=tricmin
+     else
+        CALL DclGetShadeLevel( 1, clev1, clev2, tricmin_num )
+        write(*,*) "### downer color is", tricmin_num
+     end if
+
+     if(present(tricmax))then
+        tricmax_num=tricmax
+     else
+        CALL DclGetShadeLevel( color_num+2, clev1, clev2, tricmax_num )
+        write(*,*) "### upper color is", tricmax_num
+     end if
+
+     select case(trigle)
+     case('a')
+        triux(1)=vx_min
+        triux(2)=(vx_max+vx_min)*0.5
+        triux(3)=vx_max
+        triuy(1)=vy_max
+        triuy(2)=vy_max+factoru*(vx_max-vx_min)
+        triuy(3)=triuy(1)
+        tridx=triux
+        tridy(1)=vy_min
+        tridy(2)=vy_min-factoru*(vx_max-vx_min)
+        tridy(3)=tridy(1)
+     case('u')
+        triux(1)=vx_min
+        triux(2)=(vx_max+vx_min)*0.5
+        triux(3)=vx_max
+        triuy(1)=vy_max
+        triuy(2)=vy_max+factoru*(vx_max-vx_min)
+        triuy(3)=triuy(1)
+     case('d')
+        tridx(1)=vx_min
+        tridx(2)=(vx_max+vx_min)*0.5
+        tridx(3)=vx_max
+        tridy(1)=vy_min
+        tridy(2)=vy_min-factoru*(vx_max-vx_min)
+        tridy(3)=tridy(1)
+     end select
+  end if
+
 !-- ޤ
 
   call GRFIG
@@ -1632,6 +1717,24 @@ subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max, vy_min, vy
   CALL UYSFMT( form_types )
   CALL UYAXNM( 'R', coldim1, color_num+1, coldim2, color_num/2+1 )
   CALL UYAXNM( 'L', coldim1, color_num+1, coldim2, color_num/2+1 )
+
+!-- ºݤ˻ѷΰ + ѷα
+  if(present(trigle))then
+     select case(trigle)
+     case('a')
+        call DclShadeRegionNormalized( triux, triuy, tricmax_num )
+        call DclShadeRegionNormalized( tridx, tridy, tricmin_num )
+        call DclDrawLineNormalized( triux, triuy, index=13 )
+        call DclDrawLineNormalized( tridx, tridy, index=13 )
+     case('u')
+        call DclShadeRegionNormalized( triux, triuy, tricmax_num )
+        call DclDrawLineNormalized( triux, triuy, index=13 )
+     case('d')
+        call DclShadeRegionNormalized( tridx, tridy, tricmin_num )
+        call DclDrawLineNormalized( tridx, tridy, index=13 )
+     end select
+  end if
+
 !  CALL UYAXDV( 'R', (shade_max-shade_min)/real(color_num), (shade_max-shade_min)/real(0.5*color_num) )
 !  CALL UYAXDV( 'L', (shade_max-shade_min)/real(color_num), (shade_max-shade_min)/real(0.5*color_num) )
 
@@ -1698,7 +1801,8 @@ subroutine color_setting( color_num, val_min, val_max, col_tab,   &
   integer :: cmap_min, cmap_max
   real :: tlev1, tlev2
   logical :: rev
-  real :: white_min, black_max, RMISS
+  real :: white_min, black_max
+  real :: RMISS
   integer :: white, black, ITON
 
 !-- Dcl ¦ undef ͥå
